# Generated by roxygen2: do not edit by hand

S3method(coef,vbpm_fit)
S3method(fit_stats,vbfa)
S3method(fit_stats,vbmimic)
S3method(fit_stats,vbpm_fit)
S3method(plot,pefa)
S3method(print,pefa)
S3method(print,special_effects)
S3method(print,summary.pefa)
S3method(print,vbpm_fit)
S3method(summary,pefa)
export(fit_stats)
export(pefa)
export(sim_fa)
export(sim_lvm)
export(special_effects)
export(ssl)
export(vbfa)
export(vbmimic)
importFrom(MASS,mvrnorm)
importFrom(Rcpp,evalCpp)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(stats,cor)
importFrom(stats,cov2cor)
importFrom(stats,plogis)
importFrom(stats,rbinom)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
useDynLib(vbpm, .registration = TRUE)
