# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

my_quic_cpp <- function(J, S, Rho, eps, max_iter_quic) {
    .Call(`_vbpm_my_quic_cpp`, J, S, Rho, eps, max_iter_quic)
}

