#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @useDynLib vbpm, .registration = TRUE
#' @importFrom Rcpp evalCpp
#' @importFrom stats cor cov2cor plogis runif sd rbinom setNames
## usethis namespace: end
NULL
