% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{nlsy27}
\alias{nlsy27}
\title{National Longitudinal Survey of Youth 1997 (27 items)}
\format{
A list with three components:
\describe{
\item{dat}{A \verb{3458 x 27} data frame of item responses (17 polytomous
items, 10 continuous), containing \code{NA}s.}
\item{Q}{A \verb{27 x 3} initial design matrix with two to three specified
loadings per factor, in the \code{-1/0/1} coding used by \code{\link[=vbfa]{vbfa()}}.}
\item{cati}{Indices of the 17 polytomous items.}
}
}
\source{
Bureau of Labor Statistics, U.S. Department of Labor. National
Longitudinal Survey of Youth 1997 cohort. Previously distributed in the
LAWBL package (Chen, 2022).
}
\usage{
nlsy27
}
\description{
Responses of 3,458 individuals to 27 mixed-type items, with 1.12\% missing
data. Carried over from the LAWBL package (which \code{vbpm} supersedes) for
empirical illustration of the estimators.
}
\examples{
data(nlsy27)
dim(nlsy27$dat)
nlsy27$Q
}
\keyword{datasets}
